@@ -3,8 +3,7 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-
-import Capabilities from './capabilities.js';
+import Capabilities from 'gmp/capabilities/capabilities.js';
 
 class EverythingCapabilities extends Capabilities {
   constructor() {
@@ -13,5 +12,3 @@ class EverythingCapabilities extends Capabilities {
 }
 
 export default EverythingCapabilities;
-
-// vim: set ts=2 sw=2 tw=80:
