@@ -4,10 +4,9 @@
  */
 
 import registerCommand from 'gmp/command';
-
+import HttpCommand from 'gmp/commands/http';
 import {parseSeverity} from 'gmp/parser';
 
-import HttpCommand from './http';
 
 class CvssCalculator extends HttpCommand {
   constructor(http) {
@@ -26,5 +25,3 @@ class CvssCalculator extends HttpCommand {
 }
 
 registerCommand('cvsscalculator', CvssCalculator);
-
-// vim: set ts=2 sw=2 tw=80:
