@@ -3,13 +3,10 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import {isDefined} from 'gmp/utils/identity';
-
-import logger from 'gmp/log';
-
+import GmpCommand, {BULK_SELECT_BY_IDS} from 'gmp/commands/gmp';
 import DefaultTransform from 'gmp/http/transform/default';
-
-import GmpCommand, {BULK_SELECT_BY_IDS} from './gmp';
+import logger from 'gmp/log';
+import {isDefined} from 'gmp/utils/identity';
 
 const log = logger.getLogger('gmp.commands.entity');
 
@@ -94,7 +91,7 @@ class EntityCommand extends GmpCommand {
     return this.httpPost(params, {transform: DefaultTransform});
   }
 
-  getElementFromRoot(root) {
+  getElementFromRoot() {
     throw new Error(
       'getElementFromRoot not implemented in ' + this.constructor.name,
     );
@@ -102,5 +99,3 @@ class EntityCommand extends GmpCommand {
 }
 
 export default EntityCommand;
-
-// vim: set ts=2 sw=2 tw=80:
