@@ -4,15 +4,12 @@
  */
 
 import registerCommand from 'gmp/command';
-
+import EntitiesCommand from 'gmp/commands/entities';
+import EntityCommand from 'gmp/commands/entity';
 import logger from 'gmp/log';
-
+import Group from 'gmp/models/group';
 import {isArray} from 'gmp/utils/identity';
 
-import Group from 'gmp/models/group';
-
-import EntitiesCommand from './entities';
-import EntityCommand from './entity';
 
 const log = logger.getLogger('gmp.commands.groups');
 
@@ -63,5 +60,3 @@ class GroupsCommand extends EntitiesCommand {
 
 registerCommand('group', GroupCommand);
 registerCommand('groups', GroupsCommand);
-
-// vim: set ts=2 sw=2 tw=80:
