@@ -4,10 +4,9 @@
  */
 
 import registerCommand from 'gmp/command';
-
+import GMPCommand from 'gmp/commands/gmp';
 import {License} from 'gmp/models/license';
 
-import GMPCommand from './gmp';
 
 export class LicenseCommand extends GMPCommand {
   constructor(http) {
@@ -33,5 +32,3 @@ export class LicenseCommand extends GMPCommand {
 }
 
 registerCommand('license', LicenseCommand);
-
-// vim: set ts=2 sw=2 tw=80:
