@@ -3,11 +3,10 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
+import registerCommand from 'gmp/command';
+import HttpCommand from 'gmp/commands/http';
 import {isDefined, isArray} from 'gmp/utils/identity';
 
-import HttpCommand from './http';
-
-import registerCommand from 'gmp/command';
 
 class PerformanceCommand extends HttpCommand {
   constructor(http) {
@@ -33,5 +32,3 @@ class PerformanceCommand extends HttpCommand {
 }
 
 registerCommand('performance', PerformanceCommand);
-
-// vim: set ts=2 sw=2 tw=80:
