@@ -4,15 +4,12 @@
  */
 
 import registerCommand from 'gmp/command';
-
+import EntitiesCommand from 'gmp/commands/entities';
+import EntityCommand from 'gmp/commands/entity';
 import logger from 'gmp/log';
-
+import Role from 'gmp/models/role';
 import {isArray} from 'gmp/utils/identity';
 
-import Role from 'gmp/models/role';
-
-import EntitiesCommand from './entities';
-import EntityCommand from './entity';
 
 const log = logger.getLogger('gmp.commands.roles');
 
@@ -61,5 +58,3 @@ class RolesCommand extends EntitiesCommand {
 
 registerCommand('role', RoleCommand);
 registerCommand('roles', RolesCommand);
-
-// vim: set ts=2 sw=2 tw=80:
