@@ -3,19 +3,16 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
+import registerCommand from 'gmp/command';
+import EntitiesCommand from 'gmp/commands/entities';
+import EntityCommand from 'gmp/commands/entity';
 import logger from 'gmp/log';
-
+import Nvt from 'gmp/models/nvt';
+import ScanConfig from 'gmp/models/scanconfig';
+import {YES_VALUE, NO_VALUE} from 'gmp/parser';
 import {forEach, map} from 'gmp/utils/array';
 import {isDefined} from 'gmp/utils/identity';
 
-import registerCommand from 'gmp/command';
-import {YES_VALUE, NO_VALUE} from 'gmp/parser';
-
-import Nvt from 'gmp/models/nvt';
-import ScanConfig from 'gmp/models/scanconfig';
-
-import EntitiesCommand from './entities';
-import EntityCommand from './entity';
 
 const log = logger.getLogger('gmp.commands.scanconfigs');
 
@@ -161,7 +158,7 @@ export class ScanConfigCommand extends EntityCommand {
       timeout: isDefined(timeout) ? 1 : 0,
     };
 
-    data['preference:scanner:0:scanner:timeout.' + oid] = isDefined(timeout)
+    data['preference:' + oid + ':0:entry:timeout'] = isDefined(timeout)
       ? timeout
       : '';
 
@@ -212,5 +209,3 @@ class ScanConfigsCommand extends EntitiesCommand {
 
 registerCommand('scanconfig', ScanConfigCommand);
 registerCommand('scanconfigs', ScanConfigsCommand);
-
-// vim: set ts=2 sw=2 tw=80:
