@@ -3,14 +3,12 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import logger from 'gmp/log';
-
 import registerCommand from 'gmp/command';
-
+import EntitiesCommand from 'gmp/commands/entities';
+import EntityCommand from 'gmp/commands/entity';
+import logger from 'gmp/log';
 import Schedule from 'gmp/models/schedule';
 
-import EntitiesCommand from './entities';
-import EntityCommand from './entity';
 
 const log = logger.getLogger('gmp.commands.schedules');
 
@@ -63,5 +61,3 @@ class SchedulesCommand extends EntitiesCommand {
 
 registerCommand('schedule', ScheduleCommand);
 registerCommand('schedules', SchedulesCommand);
-
-// vim: set ts=2 sw=2 tw=80:
