@@ -3,14 +3,13 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import Ticket from 'gmp/models/ticket';
-
-import EntitiesCommand from './entities';
-import EntityCommand from './entity';
-
 import registerCommand from 'gmp/command';
+import EntitiesCommand from 'gmp/commands/entities';
+import EntityCommand from 'gmp/commands/entity';
+import Ticket from 'gmp/models/ticket';
 import {isDefined} from 'gmp/utils/identity';
 
+
 const convertNote = note => {
   if (!isDefined(note)) {
     return note;
@@ -64,5 +63,3 @@ export class TicketsCommand extends EntitiesCommand {
 
 registerCommand('tickets', TicketsCommand);
 registerCommand('ticket', TicketCommand);
-
-// vim: set ts=2 sw=2 tw=80:
