@@ -3,30 +3,24 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import logger from 'gmp/log';
-
-import registerCommand from 'gmp/command';
-
-import {forEach, map} from 'gmp/utils/array';
-import {isArray, isDefined} from 'gmp/utils/identity';
-import {severityValue} from 'gmp/utils/number';
-
 import Capabilities from 'gmp/capabilities/capabilities';
-
+import registerCommand from 'gmp/command';
+import EntitiesCommand from 'gmp/commands/entities';
+import EntityCommand from 'gmp/commands/entity';
+import logger from 'gmp/log';
 import moment from 'gmp/models/date';
-
+import Setting from 'gmp/models/setting';
+import Settings from 'gmp/models/settings';
 import User, {
   AUTH_METHOD_LDAP,
   AUTH_METHOD_NEW_PASSWORD,
   AUTH_METHOD_RADIUS,
 } from 'gmp/models/user';
-import Setting from 'gmp/models/setting';
-import Settings from 'gmp/models/settings';
-
 import {parseInt} from 'gmp/parser';
+import {forEach, map} from 'gmp/utils/array';
+import {isArray, isDefined} from 'gmp/utils/identity';
+import {severityValue} from 'gmp/utils/number';
 
-import EntitiesCommand from './entities';
-import EntityCommand from './entity';
 
 const log = logger.getLogger('gmp.commands.users');
 
@@ -355,7 +349,7 @@ export class UserCommand extends EntityCommand {
 
       try {
         defaults = JSON.parse(value);
-      } catch (e) {
+      } catch {
         log.warn(
           'Could not parse saved report composer defaults, setting ' +
             'back to default defaults...',
@@ -411,5 +405,3 @@ class UsersCommand extends EntitiesCommand {
 
 registerCommand('user', UserCommand);
 registerCommand('users', UsersCommand);
-
-// vim: set ts=2 sw=2 tw=80:
