@@ -3,10 +3,9 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import Http from './http';
-import {buildServerUrl} from './utils';
-
-import transform from './transform/fastxml';
+import Http from 'gmp/http/http';
+import transform from 'gmp/http/transform/fastxml';
+import {buildServerUrl} from 'gmp/http/utils';
 
 class GmpHttp extends Http {
   constructor(settings) {
@@ -26,5 +25,3 @@ class GmpHttp extends Http {
 }
 
 export default GmpHttp;
-
-// vim: set ts=2 sw=2 tw=80:
