@@ -3,22 +3,17 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import logger from 'gmp/log';
-
-import _ from 'gmp/locale';
-
-import {isDefined, hasValue, isArray} from '../utils/identity';
-
-import Rejection from './rejection';
-import Response from './response';
-
-import DefaultTransform from './transform/default';
-
+import Rejection from 'gmp/http/rejection';
+import Response from 'gmp/http/response';
+import DefaultTransform from 'gmp/http/transform/default';
 import {
   buildUrlParams,
   getFeedAccessStatusMessage,
   findActionInXMLString,
-} from './utils';
+} from 'gmp/http/utils';
+import _ from 'gmp/locale';
+import logger from 'gmp/log';
+import {isDefined, hasValue, isArray} from 'gmp/utils/identity';
 
 const log = logger.getLogger('gmp.http');
 
@@ -218,7 +213,7 @@ class Http {
     );
     try {
       reject(this.transformRejection(rej, options));
-    } catch (error) {
+    } catch {
       reject(rej);
     }
   }
@@ -233,7 +228,7 @@ class Http {
     );
     try {
       reject(this.transformRejection(rej, options));
-    } catch (error) {
+    } catch {
       reject(rej);
     }
   }
@@ -254,5 +249,3 @@ class Http {
 }
 
 export default Http;
-
-// vim: set ts=2 sw=2 tw=80:
