@@ -4,21 +4,17 @@
  */
 
 import {XMLParser} from 'fast-xml-parser';
-
+import {success, rejection} from 'gmp/http/transform/xml';
 import {parseEnvelopeMeta, parseXmlEncodedString} from 'gmp/parser';
-
 import {isDefined} from 'gmp/utils/identity';
 
-import {success, rejection} from './xml';
-
 const PARSER_OPTIONS = {
   attributeNamePrefix: '_',
   ignoreAttributes: false,
   removeNSPrefix: true,
   textNodeName: '__text',
-  attributeValueProcessor: (name, value, jPath) => parseXmlEncodedString(value),
-  tagValueProcessor: (name, value, jPath, hasAttributes, isLeafNode) =>
-    parseXmlEncodedString(value),
+  attributeValueProcessor: (_name, value) => parseXmlEncodedString(value),
+  tagValueProcessor: (_name, value) => parseXmlEncodedString(value),
 };
 
 const xmlParser = new XMLParser(PARSER_OPTIONS);
