@@ -3,11 +3,9 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import {_} from 'gmp/locale/lang';
-
-import {isDefined} from 'gmp/utils/identity';
-
 import Rejection from 'gmp/http//rejection';
+import {_} from 'gmp/locale/lang';
+import {isDefined} from 'gmp/utils/identity';
 
 export const success =
   transform =>
@@ -28,7 +26,7 @@ export const success =
     }
   };
 
-export const rejection = transform => (rej, options) => {
+export const rejection = transform => rej => {
   if (rej.isError && rej.isError()) {
     const data = transform(rej);
     if (!isDefined(data)) {
