@@ -3,19 +3,16 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
+import {setDateLocale} from 'gmp/locale/date';
+import Detector from 'gmp/locale/detector';
+import {getLanguageCodes} from 'gmp/locale/languages';
+import logger from 'gmp/log';
+import {isDefined} from 'gmp/utils/identity';
+import {split} from 'gmp/utils/string';
 import i18next from 'i18next';
 import HttpBackend from 'i18next-http-backend';
 import {initReactI18next} from 'react-i18next';
 
-import logger from 'gmp/log';
-
-import {isDefined} from 'gmp/utils/identity';
-
-import {setLocale as setDateLocale} from './date';
-import Detector from './detector';
-import {getLanguageCodes} from './languages';
-import {split} from 'gmp/utils/string';
-
 const log = logger.getLogger('gmp.locale.lang');
 
 let languageChangelisteners = [];
@@ -43,6 +40,7 @@ const I18N_OPTIONS = {
   },
   supportedLngs: whitelist,
   nonExplicitSupportedLngs: false,
+  returnEmptyString: false,
   interpolation: {
     skipOnVariables: false,
   },
@@ -132,5 +130,3 @@ const translateLazy = (key, options) => new LazyTranslate(key, options);
 
 export {translate as _};
 export {translateLazy as _l};
-
-// vim: set ts=2 sw=2 tw=80:
