@@ -4,14 +4,11 @@
  */
 
 import {_l} from 'gmp/locale/lang';
-
+import Model, {parseModelFromElement} from 'gmp/model';
+import AuditReportReport from 'gmp/models/report/auditreport';
+import {parseDate} from 'gmp/parser';
 import {isDefined} from 'gmp/utils/identity';
 
-import {parseDate} from 'gmp/parser';
-
-import Model, {parseModelFromElement} from 'gmp/model';
-
-import AuditReportReport from './report/auditreport';
 
 export const COMPLIANCE_STATES = {
   yes: _l('Yes'),
@@ -19,7 +16,6 @@ export const COMPLIANCE_STATES = {
   incomplete: _l('Incomplete'),
   undefined: _l('Undefined'),
 };
-/* eslint-disable quote-props */
 
 export const getTranslatableReportCompliance = compliance =>
   `${COMPLIANCE_STATES[compliance]}`;
