@@ -3,13 +3,12 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
+import Info from 'gmp/models/info';
+import {parseSeverity, parseDate, parseBoolean} from 'gmp/parser';
+import {map} from 'gmp/utils/array';
 import {isDefined} from 'gmp/utils/identity';
 import {isEmpty} from 'gmp/utils/string';
-import {map} from 'gmp/utils/array';
 
-import Info from './info';
-
-import {parseSeverity, parseDate} from 'gmp/parser';
 
 class Cpe extends Info {
   static entityType = 'cpe';
@@ -32,7 +31,14 @@ class Cpe extends Info {
     }
 
     if (isDefined(ret.nvd_id)) {
-      ret.nvdId = ret.nvd_id;
+      // old ID from nvd just kept for backwards compatibility and should be removed in future
+      ret.cpeNameId = ret.nvd_id;
+      delete ret.nvd_id;
+    }
+
+    if (isDefined(ret.cpe_name_id)) {
+      ret.cpeNameId = ret.cpe_name_id;
+      delete ret.cpe_name_id;
     }
 
     if (isDefined(ret.update_time)) {
@@ -40,16 +46,26 @@ class Cpe extends Info {
       delete ret.update_time;
     }
 
-    if (isDefined(ret.raw_data) && isDefined(ret.raw_data['cpe-item'])) {
-      const cpeItem = ret.raw_data['cpe-item'];
-      if (isDefined(cpeItem._deprecated_by)) {
-        ret.deprecatedBy = cpeItem._deprecated_by;
-      }
+    /*
+     * This code includes a backup check for deprecated field `raw_data`.
+     * Once `raw_data` is removed from the API, this backup check can be removed.
+     */
+
+    if (isDefined(ret.deprecated)) {
+      ret.deprecated = parseBoolean(ret.deprecated);
+    } else {
+      ret.deprecated = false;
     }
+
+    if (ret.deprecated === true && isDefined(ret.deprecated_by)) {
+      ret.deprecatedBy = ret.deprecated_by._cpe_id;
+      delete ret.deprecated_by;
+    } else if (isDefined(ret.raw_data?.['cpe-item']?._deprecated_by)) {
+      ret.deprecatedBy = ret.raw_data['cpe-item']._deprecated_by;
+    }
+
     return ret;
   }
 }
 
 export default Cpe;
-
-// vim: set ts=2 sw=2 tw=80:
