@@ -3,12 +3,11 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import {isDefined} from 'gmp/utils/identity';
-import {forEach, map} from 'gmp/utils/array';
-
+import Info from 'gmp/models/info';
 import {parseSeverity} from 'gmp/parser';
+import {forEach, map} from 'gmp/utils/array';
+import {isDefined} from 'gmp/utils/identity';
 
-import Info from './info';
 
 class DfnCertAdv extends Info {
   static entityType = 'dfncert';
@@ -49,5 +48,3 @@ class DfnCertAdv extends Info {
 }
 
 export default DfnCertAdv;
-
-// vim: set ts=2 sw=2 tw=80:
