@@ -3,10 +3,9 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import {isDefined, isNumberOrNumberString} from '../../utils/identity';
-import {isEmpty} from '../../utils/string';
-
-import {parseInt, parseFloat} from '../../parser';
+import {parseInt, parseFloat} from 'gmp/parser';
+import {isDefined, isNumberOrNumberString} from 'gmp/utils/identity';
+import {isEmpty} from 'gmp/utils/string';
 
 const convertBooleanInt = (keyword, value, relation) => ({
   keyword,
@@ -20,7 +19,7 @@ const convertInt = (keyword, value, relation) => ({
   relation,
 });
 
-const convertFirst = (keyword, value, relation) => {
+const convertFirst = (keyword, value) => {
   const intValue = parseInt(value);
   return {
     keyword,
@@ -29,15 +28,14 @@ const convertFirst = (keyword, value, relation) => {
   };
 };
 
-const convertRows = (keyword, value, relation) =>
-  convertInt(keyword, value, '=');
+const convertRows = (keyword, value) => convertInt(keyword, value, '=');
 
-const convertNoRelation = (keyword, value, relation) => ({
+const convertNoRelation = (keyword, value) => ({
   keyword,
   value,
 });
 
-const convertNoRelationAndKeyword = (keyword, value, relation) => ({value});
+const convertNoRelationAndKeyword = (keyword, value) => ({value});
 
 const KEYWORD_CONVERTERS = {
   apply_overrides: convertBooleanInt,
@@ -86,5 +84,3 @@ const convert = (keyword, value, relation) => {
 };
 
 export default convert;
-
-// vim: set ts=2 sw=2 tw=80:
