@@ -3,10 +3,7 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import {isDefined} from 'gmp/utils/identity';
-import {isEmpty} from 'gmp/utils/string';
-import {forEach, map} from 'gmp/utils/array';
-
+import Asset from 'gmp/models/asset';
 import {
   parseBoolean,
   parseInt,
@@ -15,14 +12,14 @@ import {
   parseYesNo,
   setProperties,
 } from 'gmp/parser';
-
-import Asset from './asset';
+import {forEach, map} from 'gmp/utils/array';
+import {isDefined} from 'gmp/utils/identity';
+import {isEmpty} from 'gmp/utils/string';
 
 const get_identifier = (identifiers, name) =>
   identifiers.filter(identifier => identifier.name === name)[0];
 
-const newProperties = (properties, object = {}) =>
-  setProperties(parseProperties(properties, object));
+const newProperties = properties => setProperties(parseProperties(properties));
 
 class Identifier {
   constructor(element) {
@@ -115,5 +112,3 @@ class Host extends Asset {
 }
 
 export default Host;
-
-// vim: set ts=2 sw=2 tw=80:
