@@ -3,10 +3,8 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import {isModelElement} from 'gmp/utils/identity';
-import {isEmpty} from 'gmp/utils/string';
-
 import Model, {parseModelFromElement} from 'gmp/model';
+import Nvt from 'gmp/models/nvt';
 import {
   parseCsv,
   parseSeverity,
@@ -14,8 +12,9 @@ import {
   parseYesNo,
   YES_VALUE,
 } from 'gmp/parser';
+import {isModelElement} from 'gmp/utils/identity';
+import {isEmpty} from 'gmp/utils/string';
 
-import Nvt from './nvt';
 
 export const NOTE_ACTIVE_UNLIMITED_VALUE = -2;
 export const NOTE_INACTIVE_VALUE = -1;
@@ -65,5 +64,3 @@ class Note extends Model {
 }
 
 export default Note;
-
-// vim: set ts=2 sw=2 tw=80:
