@@ -3,10 +3,7 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import {isDefined, isArray, isString} from 'gmp/utils/identity';
-import {isEmpty, split} from 'gmp/utils/string';
-import {map} from 'gmp/utils/array';
-
+import Info from 'gmp/models/info';
 import {
   parseDate,
   parseFloat,
@@ -15,8 +12,10 @@ import {
   parseYesNo,
   YES_VALUE,
 } from 'gmp/parser';
+import {map} from 'gmp/utils/array';
+import {isDefined, isArray, isString} from 'gmp/utils/identity';
+import {isEmpty, split} from 'gmp/utils/string';
 
-import Info from './info';
 
 export const TAG_NA = 'N/A';
 
@@ -195,5 +194,3 @@ class Nvt extends Info {
 }
 
 export default Nvt;
-
-// vim: set ts=2 sw=2 tw=80:
