@@ -3,9 +3,10 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import Asset from './asset';
+import Asset from 'gmp/models/asset';
 import {parseSeverity} from 'gmp/parser';
 
+
 class OperatingSystem extends Asset {
   static entityType = 'operatingsystem';
 
@@ -42,5 +43,3 @@ class OperatingSystem extends Asset {
 }
 
 export default OperatingSystem;
-
-// vim: set ts=2 sw=2 tw=80:
