@@ -3,15 +3,13 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import {isDefined} from 'gmp/utils/identity';
+import Model, {parseModelFromElement} from 'gmp/model';
+import {parseCount, parseTrend} from 'gmp/models/scanconfig';
+import {parseBoolean} from 'gmp/parser';
 import {forEach, map} from 'gmp/utils/array';
+import {isDefined} from 'gmp/utils/identity';
 import {isEmpty} from 'gmp/utils/string';
 
-import {parseBoolean} from 'gmp/parser';
-
-import Model, {parseModelFromElement} from 'gmp/model';
-
-import {parseCount, parseTrend} from './scanconfig';
 
 class Policy extends Model {
   static entityType = 'policy';
@@ -122,5 +120,3 @@ class Policy extends Model {
 }
 
 export default Policy;
-
-// vim: set ts=2 sw=2 tw=80:
