@@ -3,13 +3,11 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
+import Model, {parseModelFromElement} from 'gmp/model';
+import ReportReport from 'gmp/models/report/report';
+import {parseSeverity, parseDate} from 'gmp/parser';
 import {isDefined} from 'gmp/utils/identity';
 
-import {parseSeverity, parseDate} from 'gmp/parser';
-
-import Model, {parseModelFromElement} from 'gmp/model';
-
-import ReportReport from './report/report';
 
 // FIXME the report xml structure is really ugly
 
@@ -57,5 +55,3 @@ class Report extends Model {
 }
 
 export default Report;
-
-// vim: set ts=2 sw=2 tw=80:
