@@ -3,11 +3,9 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import {isDefined} from '../../utils/identity';
-
-import {setProperties, parseSeverity} from '../../parser';
-
-import Nvt from '../nvt';
+import Nvt from 'gmp/models/nvt';
+import {setProperties, parseSeverity} from 'gmp/parser';
+import {isDefined} from 'gmp/utils/identity';
 
 class ReportCve {
   constructor() {
@@ -58,5 +56,3 @@ class ReportCve {
 }
 
 export default ReportCve;
-
-// vim: set ts=2 sw=2 tw=80:
