@@ -3,29 +3,24 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import {isDefined} from 'gmp/utils/identity';
-import {isEmpty} from 'gmp/utils/string';
-import {filter as filter_func, forEach, map} from 'gmp/utils/array';
-
-import {parseBoolean, parseSeverity, parseDate} from 'gmp/parser';
-
+import CollectionCounts from 'gmp/collection/collectioncounts';
 import {
   parseCollectionList,
   parseFilter,
   parseReportResultEntities,
 } from 'gmp/collection/parser';
-
-import CollectionCounts from 'gmp/collection/collectioncounts';
-
-import ReportApp from './app';
-import ReportCve from './cve';
-import ReportHost from './host';
-import ReportOperatingSystem from './os';
-import ReportPort from './port';
-import ReportTLSCertificate from './tlscertificate';
-
-import Result from '../result';
-import {getRefs, hasRefType} from '../nvt';
+import {getRefs, hasRefType} from 'gmp/models/nvt';
+import ReportApp from 'gmp/models/report/app';
+import ReportCve from 'gmp/models/report/cve';
+import ReportHost from 'gmp/models/report/host';
+import ReportOperatingSystem from 'gmp/models/report/os';
+import ReportPort from 'gmp/models/report/port';
+import ReportTLSCertificate from 'gmp/models/report/tlscertificate';
+import Result from 'gmp/models/result';
+import {parseBoolean, parseSeverity, parseDate} from 'gmp/parser';
+import {filter as filter_func, forEach, map} from 'gmp/utils/array';
+import {isDefined} from 'gmp/utils/identity';
+import {isEmpty} from 'gmp/utils/string';
 
 // reports with details=1 always have a results element
 // (that can be empty) whereas reports with details=0
@@ -412,7 +407,7 @@ const parse_report_report_counts = elem => {
   return new CollectionCounts(counts);
 };
 
-export const parseResults = (report, filter) => {
+export const parseResults = report => {
   const {results, result_count, compliance_count} = report;
 
   if (
@@ -631,5 +626,3 @@ export const parseCves = (report, filter) => {
     filter: isDefined(filter) ? filter : parseFilter(report),
   };
 };
-
-// vim: set ts=2 sw=2 tw=80:
