@@ -3,9 +3,8 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import {isDefined} from '../../utils/identity';
-
-import {setProperties, parseInt, parseSeverity} from '../../parser';
+import {setProperties, parseInt, parseSeverity} from 'gmp/parser';
+import {isDefined} from 'gmp/utils/identity';
 
 class ReportPort {
   constructor() {
@@ -64,5 +63,3 @@ class ReportPort {
 }
 
 export default ReportPort;
-
-// vim: set ts=2 sw=2 tw=80:
