@@ -3,17 +3,8 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import {isDefined} from '../../utils/identity';
-import {isEmpty} from '../../utils/string';
-
-import {parseSeverity, parseDate} from '../../parser';
-
-import {parseFilter} from '../../collection/parser';
-
-import Model from '../../model';
-
-import ReportTask from './task';
-
+import {parseFilter} from 'gmp/collection/parser';
+import Model from 'gmp/model';
 import {
   parseApps,
   parseClosedCves,
@@ -24,7 +15,11 @@ import {
   parsePorts,
   parseResults,
   parseTlsCertificates,
-} from './parser';
+} from 'gmp/models/report/parser';
+import ReportTask from 'gmp/models/report/task';
+import {parseSeverity, parseDate} from 'gmp/parser';
+import {isDefined} from 'gmp/utils/identity';
+import {isEmpty} from 'gmp/utils/string';
 
 class ReportReport extends Model {
   static entityType = 'report';
@@ -119,5 +114,3 @@ class ReportReport extends Model {
 }
 
 export default ReportReport;
-
-// vim: set ts=2 sw=2 tw=80:
