@@ -3,12 +3,10 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import {isDefined} from '../../utils/identity';
-import {isEmpty} from '../../utils/string';
-
-import {parseProgressElement} from '../../parser';
-
-import Model, {parseModelFromElement} from '../../model';
+import Model, {parseModelFromElement} from 'gmp/model';
+import {parseProgressElement} from 'gmp/parser';
+import {isDefined} from 'gmp/utils/identity';
+import {isEmpty} from 'gmp/utils/string';
 
 /*
  * Use own task model for reports to avoid cyclic dependencies
@@ -38,5 +36,3 @@ class ReportTask extends Model {
 }
 
 export default ReportTask;
-
-// vim: set ts=2 sw=2 tw=80:
