@@ -3,20 +3,16 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
+import Model, {parseModelFromElement} from 'gmp/model';
+import Cve from 'gmp/models/cve';
+import Note from 'gmp/models/note';
+import Nvt from 'gmp/models/nvt';
+import Override from 'gmp/models/override';
+import {parseSeverity, parseQod} from 'gmp/parser';
 import {forEach, map} from 'gmp/utils/array';
 import {isDefined, isString} from 'gmp/utils/identity';
 import {isEmpty} from 'gmp/utils/string';
 
-import Model, {parseModelFromElement} from 'gmp/model';
-import {parseSeverity, parseQod} from 'gmp/parser';
-
-import Nvt from './nvt';
-
-import Note from './note';
-
-import Override from './override';
-import Cve from './cve';
-
 export class Delta {
   static TYPE_NEW = 'new';
   static TYPE_SAME = 'same';
@@ -153,5 +149,3 @@ class Result extends Model {
 }
 
 export default Result;
-
-// vim: set ts=2 sw=2 tw=80:
