@@ -4,12 +4,11 @@
  */
 
 import logger from 'gmp/log';
-import {isDefined} from 'gmp/utils/identity';
-import {map} from 'gmp/utils/array';
-
 import Model, {parseModelFromElement} from 'gmp/model';
+import Event from 'gmp/models/event';
+import {map} from 'gmp/utils/array';
+import {isDefined} from 'gmp/utils/identity';
 
-import Event from './event';
 
 const log = logger.getLogger('gmp.models.schedule');
 
@@ -59,5 +58,3 @@ class Schedule extends Model {
 }
 
 export default Schedule;
-
-// vim: set ts=2 sw=2 tw=80:
