@@ -4,10 +4,9 @@
  */
 
 import {_} from 'gmp/locale/lang';
-
+import Info from 'gmp/models/info';
 import {isDefined} from 'gmp/utils/identity';
 
-import Info from './info';
 
 export const secInfoTypeName = (type, unknown) => {
   if (!isDefined(unknown)) {
@@ -58,5 +57,3 @@ class SecInfo extends Info {
 }
 
 export default SecInfo;
-
-// vim: set ts=2 sw=2 tw=80:
