@@ -4,7 +4,6 @@
  */
 
 import {test, expect} from '@gsa/testing';
-
 import {isDate} from 'gmp/models/date';
 import {parseDate, NO_VALUE, YES_VALUE} from 'gmp/parser';
 
@@ -26,7 +25,11 @@ const testId = modelClass => {
   });
 };
 
-export const testModelFromElement = (modelClass, type) => {
+export const testModelFromElement = (
+  modelClass,
+  type,
+  {testName = true} = {},
+) => {
   test('should create instance of modelclass in fromElement', () => {
     const model = modelClass.fromElement();
     expect(model).toBeInstanceOf(modelClass);
@@ -153,6 +156,14 @@ export const testModelFromElement = (modelClass, type) => {
 
     expect(model.type).toBeUndefined();
   });
+
+  if (testName) {
+    test('should ensure name is parsed as string', () => {
+      const model = modelClass.fromElement({name: 1337});
+
+      expect(model.name).toEqual('1337');
+    });
+  }
 };
 
 export const testModelMethods = (modelClass, {testIsActive = true} = {}) => {
@@ -293,11 +304,9 @@ const testModelGetProperties = (modelClass, type) => {
 };
 
 export const testModel = (modelClass, type, options) => {
-  testModelFromElement(modelClass, type);
+  testModelFromElement(modelClass, type, options);
   testModelMethods(modelClass, options);
   testModelSetProperties(modelClass);
   testModelGetProperties(modelClass, type);
   testId(modelClass);
 };
-
-// vim: set ts=2 sw=2 tw=80:
