@@ -3,7 +3,7 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import {hasValue, isDefined, isArray} from './identity';
+import {hasValue, isDefined, isArray} from 'gmp/utils/identity';
 
 export const forEach = (array, func) => {
   if (!hasValue(array) || !isDefined(func)) {
@@ -101,5 +101,3 @@ export const arraysEqual = (arr1, arr2) => {
   }
   return true;
 };
-
-// vim: set ts=2 sw=2 tw=80:
