@@ -3,7 +3,7 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import {isDefined} from './identity';
+import {isDefined} from 'gmp/utils/identity';
 
 /**
  * Formats a Number to a fixed number of digits to appear after the decimal
@@ -28,5 +28,3 @@ export const fixedValue = (value, digits) =>
  * @returns {String} Formatted Severity
  */
 export const severityValue = severity => fixedValue(severity, 1);
-
-// vim: set ts=2 sw=2 tw=80:
