@@ -3,12 +3,11 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import React from 'react';
-
 import {isDefined} from 'gmp/utils/identity';
+import React from 'react';
+import withFilterSelection from 'web/components/dashboard/display/withFilterSelection';
+import PropTypes from 'web/utils/PropTypes';
 
-import PropTypes from 'web/utils/proptypes';
-import withFilterSelection from './withFilterSelection';
 
 const createDisplay = ({
   chartComponent: Chart,
@@ -52,5 +51,3 @@ const createDisplay = ({
 };
 
 export default createDisplay;
-
-// vim: set ts=2 sw=2 tw=80:
