@@ -3,22 +3,21 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import React, {useCallback} from 'react';
-
 import {DatePickerInput} from '@greenbone/opensight-ui-components-mantinev7';
-
-import {isDefined} from 'gmp/utils/identity';
-
-import date from 'gmp/models/date';
-
 import {getLocale} from 'gmp/locale/lang';
+import date from 'gmp/models/date';
+import {isDefined} from 'gmp/utils/identity';
+import React, {useCallback} from 'react';
+import PropTypes from 'web/utils/PropTypes';
 
-import PropTypes from 'web/utils/proptypes';
-
-const DatePickerComponent = (
-  {disabled, minDate = date(), name, value = date(), onChange, label = ''},
-  ref,
-) => {
+const DatePickerComponent = ({
+  disabled,
+  minDate = date(),
+  name,
+  value = date(),
+  onChange,
+  label = '',
+}) => {
   const handleChange = useCallback(
     newValue => {
       if (isDefined(onChange)) {
@@ -31,24 +30,25 @@ const DatePickerComponent = (
 
   return (
     <DatePickerInput
+      data-testid="datepicker-input"
       disabled={disabled}
+      label={label}
       locale={getLocale()}
-      value={value.toDate()}
-      onChange={handleChange}
+      maxDate={date().add(3, 'years').toDate()}
       minDate={
         minDate === false || !isDefined(minDate) ? undefined : minDate.toDate()
       }
-      maxDate={date().add(3, 'years').toDate()}
-      label={label}
+      value={value.toDate()}
+      onChange={handleChange}
     />
   );
 };
 
 DatePickerComponent.propTypes = {
   disabled: PropTypes.bool,
-  minDate: PropTypes.instanceOf(date),
+  minDate: PropTypes.oneOfType([PropTypes.date, PropTypes.oneOf([false])]),
   name: PropTypes.string.isRequired,
-  value: PropTypes.instanceOf(date),
+  value: PropTypes.date,
   onChange: PropTypes.func,
   label: PropTypes.string,
 };
