@@ -4,8 +4,7 @@
  */
 
 import React from 'react';
-
-import Download from './download';
+import Download from 'web/components/form/Download';
 
 const withDownload = Component => {
   class DownloadWrapper extends React.Component {
@@ -35,5 +34,3 @@ const withDownload = Component => {
 };
 
 export default withDownload;
-
-// vim: set ts=2 sw=2 tw=80:
