@@ -3,8 +3,9 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import PropTypes from 'web/utils/proptypes';
-import SvgIcon from './svgicon';
+import SvgIcon from 'web/components/icon/SvgIcon';
+import PropTypes from 'web/utils/PropTypes';
+
 
 const SvgIconWrapper = ({component: Component, size, ...props}) => (
   <SvgIcon size={size} {...props}>
@@ -13,10 +14,10 @@ const SvgIconWrapper = ({component: Component, size, ...props}) => (
 );
 
 SvgIconWrapper.propTypes = {
-  component: PropTypes.node.isRequired,
+  component: PropTypes.elementType.isRequired,
   size: PropTypes.oneOfType([
     PropTypes.oneOf(['tiny', 'small', 'medium', 'large']),
-    PropTypes.string,
+    PropTypes.arrayOf(PropTypes.string),
   ]),
 };
 
