@@ -3,14 +3,13 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import withSvgIcon from './withSvgIcon';
 
 import {X as Icon} from 'lucide-react';
-
 import IconWithStrokeWidth from 'web/components/icon/IconWithStrokeWidth';
+import withSvgIcon from 'web/components/icon/withSvgIcon';
 
 const XIcon = withSvgIcon()(props => (
-  <IconWithStrokeWidth IconComponent={Icon} {...props} />
+  <IconWithStrokeWidth IconComponent={Icon} {...props} data-testid="X-icon"/>
 ));
 
 export default XIcon;
