@@ -3,11 +3,9 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-
 import React from 'react';
-
-import DialogNotification from './dialognotification';
-import useDialogNotification from './useDialogNotification';
+import DialogNotification from 'web/components/notification/DialogNotification';
+import useDialogNotification from 'web/components/notification/useDialogNotification';
 
 const withDialogNotification = Component => {
   const DialogNotificationWrapper = props => {
@@ -24,5 +22,3 @@ const withDialogNotification = Component => {
 };
 
 export default withDialogNotification;
-
-// vim: set ts=2 sw=2 tw=80:
