@@ -3,9 +3,8 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import PropTypes from 'web/utils/proptypes';
-
 import {applianceComponent} from 'web/utils/applianceData';
+import PropTypes from 'web/utils/PropTypes';
 
 const getLogo = model => {
   const Component = applianceComponent[model];
