@@ -4,8 +4,7 @@
  */
 
 import React from 'react';
-
-import EntitiesActions from './actions';
+import EntitiesActions from 'web/entities/Actions';
 
 const withEntitiesActions = Component => {
   const EnitiesActionsWrapper = props => (
@@ -18,5 +17,3 @@ const withEntitiesActions = Component => {
 };
 
 export default withEntitiesActions;
-
-// vim: set ts=2 sw=2 tw=80:
