@@ -4,27 +4,19 @@
  */
 
 import React from 'react';
-
-import {useSearchParams} from 'react-router-dom';
-
 import {connect} from 'react-redux';
-
-import FilterProvider from 'web/entities/filterprovider';
-
-import SubscriptionProvider from 'web/components/provider/subscriptionprovider';
-import Reload from 'web/components/loading/reload';
 import withDownload from 'web/components/form/withDownload';
-import withDialogNotification from 'web/components/notification/withDialogNotifiaction'; // eslint-disable-line max-len
-
+import Reload from 'web/components/loading/Reload';
+import withDialogNotification from 'web/components/notification/withDialogNotifiaction';
+import SubscriptionProvider from 'web/components/provider/SubscriptionProvider';
+import EntitiesContainer from 'web/entities/Container';
+import FilterProvider from 'web/entities/FilterProvider';
 import {pageFilter} from 'web/store/pages/actions';
 import {renewSessionTimeout} from 'web/store/usersettings/actions';
-
-import compose from 'web/utils/compose';
-import PropTypes from 'web/utils/proptypes';
+import compose from 'web/utils/Compose';
+import PropTypes from 'web/utils/PropTypes';
 import withGmp from 'web/utils/withGmp';
 
-import EntitiesContainer from './container';
-
 const noop = () => {};
 
 const withEntitiesContainer =
@@ -39,23 +31,22 @@ const withEntitiesContainer =
   ) =>
   Component => {
     let EntitiesContainerWrapper = ({
-      children,
       filter,
       loadEntities,
       notify,
       ...props
     }) => (
       <Reload
-        reloadInterval={() => reloadInterval(props)}
-        reload={(newFilter = filter) => loadEntities(newFilter)}
         name={gmpname}
+        reload={(newFilter = filter) => loadEntities(newFilter)}
+        reloadInterval={() => reloadInterval(props)}
       >
         {({reload}) => (
           <EntitiesContainer
             {...props}
             filter={filter}
-            notify={notify}
             gmpname={gmpname}
+            notify={notify}
             reload={reload}
           >
             {pageProps => <Component {...pageProps} />}
@@ -97,15 +88,10 @@ const withEntitiesContainer =
     )(EntitiesContainerWrapper);
 
     return props => {
-      const [searchParams] = useSearchParams();
       return (
         <SubscriptionProvider>
           {({notify}) => (
-            <FilterProvider
-              fallbackFilter={fallbackFilter}
-              gmpname={gmpname}
-              locationQuery={searchParams.toString()}
-            >
+            <FilterProvider fallbackFilter={fallbackFilter} gmpname={gmpname}>
               {({filter}) => (
                 <EntitiesContainerWrapper
                   {...props}
@@ -121,5 +107,3 @@ const withEntitiesContainer =
   };
 
 export default withEntitiesContainer;
-
-// vim: set ts=2 sw=2 tw=80:
