@@ -3,32 +3,25 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import {useCallback, useEffect, useState} from 'react';
-
-import {useSearchParams} from 'react-router-dom';
-
-import {useDispatch} from 'react-redux';
-
 import {ROWS_PER_PAGE_SETTING_ID} from 'gmp/commands/users';
-
 import Filter, {
   DEFAULT_FALLBACK_FILTER,
   DEFAULT_ROWS_PER_PAGE,
   RESET_FILTER,
 } from 'gmp/models/filter';
-
 import {isDefined, hasValue} from 'gmp/utils/identity';
-
-import getPage from 'web/store/pages/selectors';
+import {useCallback, useEffect, useState} from 'react';
+import {useDispatch} from 'react-redux';
+import {useSearchParams} from 'react-router';
+import useGmp from 'web/hooks/useGmp';
+import useShallowEqualSelector from 'web/hooks/useShallowEqualSelector';
 import {pageFilter as setPageFilter} from 'web/store/pages/actions';
-import {loadUserSettingDefault} from 'web/store/usersettings/defaults/actions';
-import {getUserSettingsDefaults} from 'web/store/usersettings/defaults/selectors';
+import getPage from 'web/store/pages/selectors';
 import {loadUserSettingsDefaultFilter} from 'web/store/usersettings/defaultfilters/actions';
 import {getUserSettingsDefaultFilter} from 'web/store/usersettings/defaultfilters/selectors';
+import {loadUserSettingDefault} from 'web/store/usersettings/defaults/actions';
+import {getUserSettingsDefaults} from 'web/store/usersettings/defaults/selectors';
 
-import useGmp from 'web/hooks/useGmp';
-
-import useShallowEqualSelector from './useShallowEqualSelector';
 
 /**
  * Hook to get the default filter of a page from the store
@@ -53,14 +46,7 @@ const useDefaultFilter = pageName =>
  *          filter and function to reset the filter
  */
 
-const usePageFilter = (
-  pageName,
-  gmpName,
-  {
-    fallbackFilter,
-    locationQueryFilterString: initialLocationQueryFilterString,
-  } = {},
-) => {
+const usePageFilter = (pageName, gmpName, {fallbackFilter} = {}) => {
   const gmp = useGmp();
   const dispatch = useDispatch();
   const [searchParams, setSearchParams] = useSearchParams();
@@ -80,9 +66,7 @@ const usePageFilter = (
 
   // use null as value for not set at all
   let returnedFilter;
-  // only use searchParams directly if locationQueryFilterString is undefined
-  const locationQueryFilterString =
-    initialLocationQueryFilterString || searchParams.get('filter');
+  const locationQueryFilterString = searchParams.get('filter');
 
   const [locationQueryFilter, setLocationQueryFilter] = useState(
     hasValue(locationQueryFilterString)
@@ -141,7 +125,7 @@ const usePageFilter = (
   }
 
   if (!returnedFilter.has('rows') && isDefined(rowsPerPage)) {
-    returnedFilter = returnedFilter.set('rows', rowsPerPage);
+    returnedFilter = returnedFilter.copy().set('rows', rowsPerPage);
   }
 
   const finishedLoading =
