@@ -3,20 +3,17 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-
 import React from 'react';
-
-import Dashboard from '../../../components/dashboard/dashboard';
-
+import Dashboard from 'web/components/dashboard/Dashboard';
 import {
   CertBundCreatedDisplay,
   CertBundCreatedTableDisplay,
-} from './createddisplay';
-import {CertBundCvssDisplay, CertBundCvssTableDisplay} from './cvssdisplay';
+} from 'web/pages/certbund/dashboard/CreatedDisplay';
+import {CertBundCvssDisplay, CertBundCvssTableDisplay} from 'web/pages/certbund/dashboard/CvssDisplay';
 import {
   CertBundSeverityClassDisplay,
   CertBundSeverityClassTableDisplay,
-} from './severityclassdisplay';
+} from 'web/pages/certbund/dashboard/SeverityClassDisplay';
 
 export const CERTBUND_DASHBOARD_ID = 'a6946f44-480f-4f37-8a73-28a4cd5310c4';
 
@@ -32,8 +29,6 @@ export const CERTBUND_DISPLAYS = [
 const CertBundDashboard = props => (
   <Dashboard
     {...props}
-    id={CERTBUND_DASHBOARD_ID}
-    permittedDisplays={CERTBUND_DISPLAYS}
     defaultDisplays={[
       [
         CertBundSeverityClassDisplay.displayId,
@@ -41,9 +36,9 @@ const CertBundDashboard = props => (
         CertBundCvssDisplay.displayId,
       ],
     ]}
+    id={CERTBUND_DASHBOARD_ID}
+    permittedDisplays={CERTBUND_DISPLAYS}
   />
 );
 
 export default CertBundDashboard;
-
-// vim: set ts=2 sw=2 tw=80:
