@@ -3,17 +3,14 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-
 import React from 'react';
-
-import Dashboard from '../../../components/dashboard/dashboard';
-
-import {CpesCreatedDisplay, CpesCreatedTableDisplay} from './createddisplay';
-import {CpesCvssDisplay, CpesCvssTableDisplay} from './cvssdisplay';
+import Dashboard from 'web/components/dashboard/Dashboard';
+import {CpesCreatedDisplay, CpesCreatedTableDisplay} from 'web/pages/cpes/dashboard/CreatedDisplay';
+import {CpesCvssDisplay, CpesCvssTableDisplay} from 'web/pages/cpes/dashboard/CvssDisplay';
 import {
   CpesSeverityClassDisplay,
   CpesSeverityClassTableDisplay,
-} from './severityclassdisplay';
+} from 'web/pages/cpes/dashboard/SeverityClassDisplay';
 
 export const CPES_DASHBOARD_ID = '9cff9b4d-b164-43ce-8687-f2360afc7500';
 
@@ -29,8 +26,6 @@ export const CPES_DISPLAYS = [
 const CpesDashboard = props => (
   <Dashboard
     {...props}
-    id={CPES_DASHBOARD_ID}
-    permittedDisplays={CPES_DISPLAYS}
     defaultDisplays={[
       [
         CpesSeverityClassDisplay.displayId,
@@ -38,9 +33,9 @@ const CpesDashboard = props => (
         CpesCvssDisplay.displayId,
       ],
     ]}
+    id={CPES_DASHBOARD_ID}
+    permittedDisplays={CPES_DISPLAYS}
   />
 );
 
 export default CpesDashboard;
-
-// vim: set ts=2 sw=2 tw=80:
