@@ -3,17 +3,14 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-
 import React from 'react';
-
-import Dashboard from '../../../components/dashboard/dashboard';
-
-import {CvesCreatedDisplay, CvesCreatedTableDisplay} from './createddisplay';
-import {CvesCvssDisplay, CvesCvssTableDisplay} from './cvssdisplay';
+import Dashboard from 'web/components/dashboard/Dashboard';
+import {CvesCreatedDisplay, CvesCreatedTableDisplay} from 'web/pages/cves/dashboard/CreatedDisplay';
+import {CvesCvssDisplay, CvesCvssTableDisplay} from 'web/pages/cves/dashboard/CvssDisplay';
 import {
   CvesSeverityClassDisplay,
   CvesSeverityClassTableDisplay,
-} from './severityclassdisplay';
+} from 'web/pages/cves/dashboard/SeverityClassDisplay';
 
 export const CVES_DASHBOARD_ID = '815ddd2e-8654-46c7-a05b-d73224102240';
 
@@ -29,8 +26,6 @@ export const CVES_DISPLAYS = [
 const CvesDashboard = props => (
   <Dashboard
     {...props}
-    id={CVES_DASHBOARD_ID}
-    permittedDisplays={CVES_DISPLAYS}
     defaultDisplays={[
       [
         CvesSeverityClassDisplay.displayId,
@@ -38,9 +33,9 @@ const CvesDashboard = props => (
         CvesCvssDisplay.displayId,
       ],
     ]}
+    id={CVES_DASHBOARD_ID}
+    permittedDisplays={CVES_DISPLAYS}
   />
 );
 
 export default CvesDashboard;
-
-// vim: set ts=2 sw=2 tw=80:
