@@ -3,20 +3,17 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-
 import React from 'react';
-
-import Dashboard from '../../../components/dashboard/dashboard';
-
+import Dashboard from 'web/components/dashboard/Dashboard';
 import {
   DfnCertsCreatedDisplay,
   DfnCertsCreatedTableDisplay,
-} from './createddisplay';
-import {DfnCertCvssDisplay, DfnCertCvssTableDisplay} from './cvssdisplay';
+} from 'web/pages/dfncert/dashboard/CreatedDisplay';
+import {DfnCertCvssDisplay, DfnCertCvssTableDisplay} from 'web/pages/dfncert/dashboard/CvssDisplay';
 import {
   DfnCertSeverityClassDisplay,
   DfnCertSeverityClassTableDisplay,
-} from './severityclassdisplay';
+} from 'web/pages/dfncert/dashboard/SeverityClassDisplay';
 
 export const DFNCERT_DASHBOARD_ID = '9812ea49-682d-4f99-b3cc-eca051d1ce59';
 
@@ -32,8 +29,6 @@ export const DFNCERT_DISPLAYS = [
 const DfnCertDashboard = props => (
   <Dashboard
     {...props}
-    id={DFNCERT_DASHBOARD_ID}
-    permittedDisplays={DFNCERT_DISPLAYS}
     defaultDisplays={[
       [
         DfnCertSeverityClassDisplay.displayId,
@@ -41,9 +36,9 @@ const DfnCertDashboard = props => (
         DfnCertCvssDisplay.displayId,
       ],
     ]}
+    id={DFNCERT_DASHBOARD_ID}
+    permittedDisplays={DFNCERT_DISPLAYS}
   />
 );
 
 export default DfnCertDashboard;
-
-// vim: set ts=2 sw=2 tw=80:
