@@ -4,8 +4,7 @@
  */
 
 import _ from 'gmp/locale';
-
-import Select from 'web/components/form/select';
+import Select from 'web/components/form/Select';
 
 const Metrics = ({metrics, selectedOptions, handleOptionChange}) => {
   return Object.entries(metrics).map(([metricShort, metric]) => (
@@ -18,7 +17,6 @@ const Metrics = ({metrics, selectedOptions, handleOptionChange}) => {
         label={`${_(metric.name)} (${metricShort})`}
         name={metricShort}
         value={selectedOptions[metricShort]}
-        menuPosition="adjust"
         onChange={handleOptionChange}
       />
     </section>
