@@ -3,20 +3,17 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-
 import React from 'react';
-
-import Dashboard from '../../../components/dashboard/dashboard';
-
+import Dashboard from 'web/components/dashboard/Dashboard';
 import {
   NotesActiveDaysDisplay,
   NotesActiveDaysTableDisplay,
-} from './activedaysdisplay';
-import {NotesCreatedDisplay, NotesCreatedTableDisplay} from './createddisplay';
+} from 'web/pages/notes/dashboard/ActiveDaysDisplay';
+import {NotesCreatedDisplay, NotesCreatedTableDisplay} from 'web/pages/notes/dashboard/CreatedDisplay';
 import {
   NotesWordCloudDisplay,
   NotesWordCloudTableDisplay,
-} from './wordclouddisplay';
+} from 'web/pages/notes/dashboard/WordCloudDisplay';
 
 export const NOTES_DASHBOARD_ID = 'ce7b121-c609-47b0-ab57-fd020a0336f4a';
 
@@ -32,8 +29,6 @@ export const NOTES_DISPLAYS = [
 const NotesDashboard = props => (
   <Dashboard
     {...props}
-    id={NOTES_DASHBOARD_ID}
-    permittedDisplays={NOTES_DISPLAYS}
     defaultDisplays={[
       [
         NotesActiveDaysDisplay.displayId,
@@ -41,9 +36,9 @@ const NotesDashboard = props => (
         NotesWordCloudDisplay.displayId,
       ],
     ]}
+    id={NOTES_DASHBOARD_ID}
+    permittedDisplays={NOTES_DISPLAYS}
   />
 );
 
 export default NotesDashboard;
-
-// vim: set ts=2 sw=2 tw=80:
