@@ -3,17 +3,14 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-
 import React from 'react';
-
-import Dashboard from '../../../components/dashboard/dashboard';
-
-import {OsCvssDisplay, OsCvssTableDisplay} from './cvssdisplay';
+import Dashboard from 'web/components/dashboard/Dashboard';
+import {OsCvssDisplay, OsCvssTableDisplay} from 'web/pages/operatingsystems/dashboard/CvssDisplay';
 import {
   OsSeverityClassDisplay,
   OsSeverityClassTableDisplay,
-} from './severityclassdisplay';
-import {OsVulnScoreDisplay, OsVulnScoreTableDisplay} from './vulnscoredisplay';
+} from 'web/pages/operatingsystems/dashboard/SeverityClassDisplay';
+import {OsVulnScoreDisplay, OsVulnScoreTableDisplay} from 'web/pages/operatingsystems/dashboard/VulnScoreDisplay';
 
 export const OS_DASHBOARD_ID = 'e93b51ed-5881-40e0-bc4f-7d3268a36177';
 
@@ -29,8 +26,6 @@ export const OS_DISPLAYS = [
 const OsDashboard = props => (
   <Dashboard
     {...props}
-    id={OS_DASHBOARD_ID}
-    permittedDisplays={OS_DISPLAYS}
     defaultDisplays={[
       [
         OsSeverityClassDisplay.displayId,
@@ -38,9 +33,9 @@ const OsDashboard = props => (
         OsCvssDisplay.displayId,
       ],
     ]}
+    id={OS_DASHBOARD_ID}
+    permittedDisplays={OS_DISPLAYS}
   />
 );
 
 export default OsDashboard;
-
-// vim: set ts=2 sw=2 tw=80:
