@@ -3,23 +3,20 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-
 import React from 'react';
-
-import Dashboard from '../../../components/dashboard/dashboard';
-
+import Dashboard from 'web/components/dashboard/Dashboard';
 import {
   OverridesActiveDaysDisplay,
   OverridesActiveDaysTableDisplay,
-} from './activedaysdisplay';
+} from 'web/pages/overrides/dashboard/ActiveDaysDisplay';
 import {
   OverridesCreatedDisplay,
   OverridesCreatedTableDisplay,
-} from './createddisplay';
+} from 'web/pages/overrides/dashboard/CreatedDisplay';
 import {
   OverridesWordCloudDisplay,
   OverridesWordCloudTableDisplay,
-} from './wordclouddisplay';
+} from 'web/pages/overrides/dashboard/WordCloudDisplay';
 
 export const OVERRIDES_DASHBOARD_ID = '054862fe-0781-4527-b1aa-2113bcd16ce7';
 
@@ -35,8 +32,6 @@ export const OVERRIDES_DISPLAYS = [
 const OverridesDashboard = props => (
   <Dashboard
     {...props}
-    id={OVERRIDES_DASHBOARD_ID}
-    permittedDisplays={OVERRIDES_DISPLAYS}
     defaultDisplays={[
       [
         OverridesActiveDaysDisplay.displayId,
@@ -44,9 +39,9 @@ const OverridesDashboard = props => (
         OverridesWordCloudDisplay.displayId,
       ],
     ]}
+    id={OVERRIDES_DASHBOARD_ID}
+    permittedDisplays={OVERRIDES_DISPLAYS}
   />
 );
 
 export default OverridesDashboard;
-
-// vim: set ts=2 sw=2 tw=80:
