@@ -3,20 +3,17 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-
 import React from 'react';
-
-import Dashboard from '../../../components/dashboard/dashboard';
-
-import {ReportsCvssDisplay, ReportsCvssTableDisplay} from './cvssdisplay';
-import {
-  ReportsSeverityDisplay,
-  ReportsSeverityTableDisplay,
-} from './severityclassdisplay';
+import Dashboard from 'web/components/dashboard/Dashboard';
+import {ReportsCvssDisplay, ReportsCvssTableDisplay} from 'web/pages/reports/dashboard/CvssDisplay';
 import {
   ReportsHighResultsDisplay,
   ReportsHighResultsTableDisplay,
-} from './highresultsdisplay';
+} from 'web/pages/reports/dashboard/HighResultsDisplay';
+import {
+  ReportsSeverityDisplay,
+  ReportsSeverityTableDisplay,
+} from 'web/pages/reports/dashboard/SeverityClassDisplay';
 
 export const REPORTS_DASHBOARD_ID = 'e599bb6b-b95a-4bb2-a6bb-fe8ac69bc071';
 
@@ -32,8 +29,6 @@ export const REPORTS_DISPLAYS = [
 const ReportsDashboard = props => (
   <Dashboard
     {...props}
-    id={REPORTS_DASHBOARD_ID}
-    permittedDisplays={REPORTS_DISPLAYS}
     defaultDisplays={[
       [
         ReportsSeverityDisplay.displayId,
@@ -41,9 +36,9 @@ const ReportsDashboard = props => (
         ReportsCvssDisplay.displayId,
       ],
     ]}
+    id={REPORTS_DASHBOARD_ID}
+    permittedDisplays={REPORTS_DISPLAYS}
   />
 );
 
 export default ReportsDashboard;
-
-// vim: set ts=2 sw=2 tw=80:
