@@ -3,24 +3,21 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-
 import React from 'react';
-
-import Dashboard from '../../../components/dashboard/dashboard';
-
-import {ResultsCvssDisplay, ResultsCvssTableDisplay} from './cvssdisplay';
+import Dashboard from 'web/components/dashboard/Dashboard';
+import {ResultsCvssDisplay, ResultsCvssTableDisplay} from 'web/pages/results/dashboard/CvssDisplay';
 import {
   ResultsDescriptionWordCloudDisplay,
   ResultsDescriptionWordCloudTableDisplay,
-} from './descriptionwordclouddisplay';
+} from 'web/pages/results/dashboard/DescriptionWordCloudDisplay';
 import {
   ResultsSeverityDisplay,
   ResultsSeverityTableDisplay,
-} from './severityclassdisplay';
+} from 'web/pages/results/dashboard/SeverityClassDisplay';
 import {
   ResultsWordCloudDisplay,
   ResultsWordCloudTableDisplay,
-} from './wordclouddisplay';
+} from 'web/pages/results/dashboard/WordCloudDisplay';
 
 export const RESULTS_DASHBOARD_ID = '0b8ae70d-d8fc-4418-8a72-e65ac8d2828e';
 
@@ -38,14 +35,12 @@ export const RESULTS_DISPLAYS = [
 const ResultsDashboard = props => (
   <Dashboard
     {...props}
-    id={RESULTS_DASHBOARD_ID}
-    permittedDisplays={RESULTS_DISPLAYS}
     defaultDisplays={[
       [ResultsSeverityDisplay.displayId, ResultsCvssDisplay.displayId],
     ]}
+    id={RESULTS_DASHBOARD_ID}
+    permittedDisplays={RESULTS_DISPLAYS}
   />
 );
 
 export default ResultsDashboard;
-
-// vim: set ts=2 sw=2 tw=80:
