@@ -4,18 +4,16 @@
  */
 
 import React from 'react';
-
-import Dashboard from 'web/components/dashboard/dashboard';
-
-import {TicketsStatusDisplay, TicketsStatusTableDisplay} from './statusdisplay';
-import {
-  TicketsAssignedUsersDisplay,
-  TicketsAssignedUsersTableDisplay,
-} from './usersassigneddisplay';
+import Dashboard from 'web/components/dashboard/Dashboard';
 import {
   TicketsCreatedDisplay,
   TicketsCreatedTableDisplay,
-} from './createddisplay';
+} from 'web/pages/tickets/dashboard/CreatedDisplay';
+import {TicketsStatusDisplay, TicketsStatusTableDisplay} from 'web/pages/tickets/dashboard/StatusDisplay';
+import {
+  TicketsAssignedUsersDisplay,
+  TicketsAssignedUsersTableDisplay,
+} from 'web/pages/tickets/dashboard/UsersAssignedDisplay';
 
 export const TICKETS_DASHBOARD_ID = '70b0626f-a835-478e-8194-e09f97887a15';
 
@@ -31,8 +29,6 @@ export const TICKETS_DISPLAYS = [
 const TicketsDashboard = props => (
   <Dashboard
     {...props}
-    id={TICKETS_DASHBOARD_ID}
-    permittedDisplays={TICKETS_DISPLAYS}
     defaultDisplays={[
       [
         TicketsStatusDisplay.displayId,
@@ -40,9 +36,9 @@ const TicketsDashboard = props => (
         TicketsCreatedDisplay.displayId,
       ],
     ]}
+    id={TICKETS_DASHBOARD_ID}
+    permittedDisplays={TICKETS_DISPLAYS}
   />
 );
 
 export default TicketsDashboard;
-
-// vim: set ts=2 sw=2 tw=80:
