@@ -3,16 +3,13 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-
 import React from 'react';
-
-import Dashboard from 'web/components/dashboard/dashboard';
-
-import {TimeStatusDisplay, TimeStatusTableDisplay} from './timestatusdisplay';
+import Dashboard from 'web/components/dashboard/Dashboard';
 import {
   TlsCertificatesModifiedDisplay,
   TlsCertificatesModifiedTableDisplay,
-} from './modifieddisplay';
+} from 'web/pages/tlscertificates/dashboard/ModifiedDisplay';
+import {TimeStatusDisplay, TimeStatusTableDisplay} from 'web/pages/tlscertificates/dashboard/TimeStatusDisplay';
 
 export const TLS_CERTIFICATES_DASHBOARD_ID =
   '9b62bf16-bf90-11e9-ad97-28d24461215b';
@@ -27,14 +24,12 @@ export const TLS_CERTFICATES_DISPLAYS = [
 const TlsCerticatesDashboard = props => (
   <Dashboard
     {...props}
-    id={TLS_CERTIFICATES_DASHBOARD_ID}
-    permittedDisplays={TLS_CERTFICATES_DISPLAYS}
     defaultDisplays={[
       [TimeStatusDisplay.displayId, TlsCertificatesModifiedDisplay.displayId],
     ]}
+    id={TLS_CERTIFICATES_DASHBOARD_ID}
+    permittedDisplays={TLS_CERTFICATES_DISPLAYS}
   />
 );
 
 export default TlsCerticatesDashboard;
-
-// vim: set ts=2 sw=2 tw=80:
