@@ -3,17 +3,14 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-
 import React from 'react';
-
-import Dashboard from '../../../components/dashboard/dashboard';
-
-import {VulnsCvssDisplay, VulnsCvssTableDisplay} from './cvssdisplay';
-import {VulnsHostsDisplay, VulnsHostsTableDisplay} from './hostsdisplay';
+import Dashboard from 'web/components/dashboard/Dashboard';
+import {VulnsCvssDisplay, VulnsCvssTableDisplay} from 'web/pages/vulns/dashboard/CvssDisplay';
+import {VulnsHostsDisplay, VulnsHostsTableDisplay} from 'web/pages/vulns/dashboard/HostsDisplay';
 import {
   VulnsSeverityDisplay,
   VulnsSeverityTableDisplay,
-} from './severityclassdisplay';
+} from 'web/pages/vulns/dashboard/SeverityClassDisplay';
 
 export const VULNS_DASHBOARD_ID = '43690dcb-3174-4d84-aa88-58c1936c7f5c';
 
@@ -29,14 +26,12 @@ export const VULNS_DISPLAYS = [
 const VulnerabilitiesDashboard = props => (
   <Dashboard
     {...props}
-    id={VULNS_DASHBOARD_ID}
-    permittedDisplays={VULNS_DISPLAYS}
     defaultDisplays={[
       [VulnsCvssDisplay.displayId, VulnsSeverityDisplay.displayId],
     ]}
+    id={VULNS_DASHBOARD_ID}
+    permittedDisplays={VULNS_DISPLAYS}
   />
 );
 
 export default VulnerabilitiesDashboard;
-
-// vim: set ts=2 sw=2 tw=80:
