@@ -3,24 +3,19 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import React from 'react';
-
-import {connect} from 'react-redux';
-
 import {isDefined, hasValue} from 'gmp/utils/identity';
-
-import compose from '../../../utils/compose';
-import withGmp from '../../../utils/withGmp';
-import withSubscription from '../../../utils/withSubscription';
-import PropTypes from '../../../utils/proptypes';
-
+import React from 'react';
+import {connect} from 'react-redux';
 import {
   receivedDashboardData,
   receivedDashboardError,
   requestDashboardData,
-} from './actions';
-
-import getDashboardData from './selectors';
+} from 'web/store/dashboard/data/actions';
+import getDashboardData from 'web/store/dashboard/data/selectors';
+import compose from 'web/utils/Compose';
+import PropTypes from 'web/utils/PropTypes';
+import withGmp from 'web/utils/withGmp';
+import withSubscription from 'web/utils/withSubscription';
 
 export const loaderPropTypes = {
   children: PropTypes.func,
@@ -61,7 +56,7 @@ class Loader extends React.Component {
     this.load = this.load.bind(this);
   }
 
-  static getDerivedStateFromProps(props, state) {
+  static getDerivedStateFromProps(props) {
     const {data} = props;
     if (isDefined(data)) {
       // Only update data if data is set and keep latest set data in state.
@@ -147,5 +142,3 @@ export default compose(
   withSubscription,
   connect(mapStateToProps, mapDispatchToProps),
 )(Loader);
-
-// vim: set ts=2 sw=2 tw=80:
