@@ -4,10 +4,10 @@
  */
 
 import {isDefined} from 'gmp/utils/identity';
-
-import {CHANGE_PAGE_FILTER} from './actions';
+import {CHANGE_PAGE_FILTER} from 'web/store/pages/actions';
 import {combineReducers} from 'web/store/utils';
 
+
 const filter = (state, action) => {
   switch (action.type) {
     case CHANGE_PAGE_FILTER:
@@ -35,5 +35,3 @@ const pageByName = (state = {}, action) => {
 };
 
 export default pageByName;
-
-// vim: set ts=2 sw=2 tw=80:
