@@ -3,11 +3,9 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import {isDefined} from 'gmp/utils/identity';
-
 import {DEFAULT_FILTER_SETTINGS} from 'gmp/commands/users';
-
-import {getUserSettingsDefaultFilter} from './selectors';
+import {isDefined} from 'gmp/utils/identity';
+import {getUserSettingsDefaultFilter} from 'web/store/usersettings/defaultfilters/selectors';
 
 export const USER_SETTINGS_DEFAULT_FILTER_LOADING_SUCCESS =
   'USER_SETTINGS_DEFAULT_FILTER_LOADING_SUCCESS';
@@ -71,5 +69,3 @@ export const loadUserSettingsDefaultFilter =
         }
       });
   };
-
-// vim: set ts=2 sw=2 two=80:
