@@ -3,11 +3,9 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import {getUserSettingsDefaults} from './selectors';
-
-import {isDefined} from 'gmp/utils/identity';
-
 import {transformSettingName} from 'gmp/commands/users';
+import {isDefined} from 'gmp/utils/identity';
+import {getUserSettingsDefaults} from 'web/store/usersettings/defaults/selectors';
 
 export const USER_SETTINGS_DEFAULTS_LOADING_REQUEST =
   'USER_SETTINGS_DEFAULTS_LOADING_REQUEST';
@@ -72,5 +70,3 @@ export const loadUserSettingDefault = gmp => id => (dispatch, getState) => {
       }
     });
 };
-
-// vim: set ts=2 sw=2 two=80:
