@@ -3,11 +3,9 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import React from 'react';
-
 import hoistStatics from 'hoist-non-react-statics';
-
-import GmpContext from '../components/provider/gmpprovider';
+import React from 'react';
+import GmpContext from 'web/components/provider/GmpProvider';
 
 const withGmp = Component => {
   const GmpWrapper = props => (
