@@ -3,11 +3,9 @@
  * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
-import React from 'react';
-
 import {isDefined} from 'gmp/utils/identity';
-
-import PropTypes from './proptypes';
+import React from 'react';
+import PropTypes from 'web/utils/PropTypes';
 
 export const withPrefix = Component => {
   const ComponentPrefixWrapper = ({prefix, ...props}) => {
@@ -27,5 +25,3 @@ export const withPrefix = Component => {
 };
 
 export default withPrefix;
-
-// vim: set ts=2 sw=2 tw=80:
