@@ -4,8 +4,7 @@
  */
 
 import React from 'react';
-
-import {SubscriptionContext} from 'web/components/provider/subscriptionprovider';
+import {SubscriptionContext} from 'web/components/provider/SubscriptionProvider';
 
 const withSubscription = Component => {
   const SubscriptionWrapper = props => (
@@ -18,5 +17,3 @@ const withSubscription = Component => {
 };
 
 export default withSubscription;
-
-// vim: set ts=2 sw=2 tw=80:
